==> haskell-transformers-compat-0.6.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.6.2
id: transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
key: transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
license: BSD-3-Clause
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
abi: 63a0e01576545fb684fe201dfb63f95d
exposed: True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal
hidden-modules: Paths_transformers_compat
import-dirs: /usr/lib/ghc-8.4.2/site-local/transformers-compat-0.6.2
library-dirs: /usr/lib/ghc-8.4.2/site-local/transformers-compat-0.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/transformers-compat-0.6.2
hs-libraries: HStransformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
depends:
    base-4.11.1.0 transformers-0.5.5.0 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             transformers-0.5.5.0=02be5c4dc3fdc926cf1b36bd484a25f8
             ghc-prim-0.5.2.0=a22477c99003a90dd639dbfd07997615
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-transformers-compat-0.6.2-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-transformers-compat.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: transformers-compat
version: 0.6.2
id: transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
key: transformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
license: BSD-3-Clause
copyright: Copyright (C) 2012-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/transformers-compat/
synopsis: A small compatibility shim for the transformers library
description:
    This package includes backported versions of types that were added
    to transformers in transformers 0.3, 0.4, and 0.5 for users who need strict
    transformers 0.2 or 0.3 compatibility to run on old versions of the
    platform, but also need those types.
    .
    Those users should be able to just depend on @transformers >= 0.2@
    and @transformers-compat >= 0.3@.
    .
    Note: missing methods are not supplied, but this at least permits the types to be used.
category: Compatibility
abi: b66628b7da4e38f285f3902fc5238513
exposed: True
exposed-modules:
    Control.Monad.Trans.Instances Data.Functor.Classes.Generic
    Data.Functor.Classes.Generic.Internal
hidden-modules: Paths_transformers_compat
import-dirs: /usr/lib/ghc-8.6.1/site-local/transformers-compat-0.6.2
library-dirs: /usr/lib/ghc-8.6.1/site-local/transformers-compat-0.6.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/transformers-compat-0.6.2
hs-libraries: HStransformers-compat-0.6.2-JV1ddSnlm3mL2xw4J4K8Kw
depends:
    base-4.12.0.0 ghc-prim-0.5.3 transformers-0.5.5.0
haddock-interfaces: /usr/share/doc/haskell-transformers-compat/html/transformers-compat.haddock
haddock-html: /usr/share/doc/haskell-transformers-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
